==> kvision-maps-js-7.4.5-sources.jar: jsMain/io/kvision/maps/externals/leaflet/layer/vector/Canvas.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

@file:JsModule("leaflet")
@file:JsNonModule

package io.kvision.maps.externals.leaflet.layer.vector

/**
 * Allows vector layers to be displayed with `<canvas>`.
 *
 * Due to [technical limitations](https://caniuse.com/canvas), Canvas is not available in all web
 * browsers, notably IE8, and overlapping geometries might not display properly in some edge cases.
 */
open external class Canvas(
    options: CanvasOptions = definedExternally
) : Renderer<Canvas.CanvasOptions> {

    interface CanvasOptions : RendererOptions {
        /** How much to extend the click tolerance around a path/object on the map. */
        var tolerance: Number?
    }
}

==> kvision-maps-js-9.0.0-sources.jar: jsMain/io/kvision/maps/externals/leaflet/layer/vector/Canvas.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

@file:JsModule("leaflet/dist/leaflet-src.esm.js")

package io.kvision.maps.externals.leaflet.layer.vector

/**
 * Allows vector layers to be displayed with `<canvas>`.
 *
 * Due to [technical limitations](https://caniuse.com/canvas), Canvas is not available in all web
 * browsers, notably IE8, and overlapping geometries might not display properly in some edge cases.
 */
open external class Canvas(
    options: CanvasOptions = definedExternally
) : Renderer<Canvas.CanvasOptions> {

    interface CanvasOptions : RendererOptions {
        /** How much to extend the click tolerance around a path/object on the map. */
        var tolerance: Number?
    }
}
